package
Version:
v0.0.0-...-31f8ae8
Opens a new window with list of versions in this module.
Published: Jan 15, 2021
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
var (
ErrDefaultResponse = &Error{"unknown error"}
ErrUnauthorized = &Error{"authentication required"}
ErrCurrencyNotSupported = &Error{"currency does not supported"}
ErrUserAgentInvalid = &Error{"invalid user-agent"}
ErrNotFound = &Error{"not found"}
)
APIErrors
ConvertQueryStringToInt64 is a function
type Error struct {
Message string
}
Error represents a Discogs API error
Source Files
¶
Click to show internal directories.
Click to hide internal directories.